@@ -83,7 +83,7 @@
 #define DCCP_SOCKOPT_TX_CCID            14
 #define DCCP_SOCKOPT_RX_CCID            15
 
-NAMESPACE_COMMONCPP
+namespace ost {
 
 typedef socket_t    SOCKET;
 
@@ -203,7 +203,7 @@ protected:
      * @param err string or message to pass.
      */
     inline void error(const char *err) const
-        {error(errExtended, err);};
+        {error(errExtended, err);}
 
     /**
      * This service is used to turn the error handler on or off for
@@ -212,7 +212,7 @@ protected:
      * @param enable true to enable handler.
      */
     inline void setError(bool enable)
-        {flags.thrown = !enable;};
+        {flags.thrown = !enable;}
 
     /**
      * Used as the default destructor for ending a socket.  This
@@ -329,6 +329,7 @@ protected:
      * @return 0 (errSuccess) on success, else error code.
      * @param ia address of multicast group to join.
      */
+    Error join(const ucommon::Socket::address &ia);
     Error join(const IPV4Multicast &ia);
 #ifdef  CCXX_IPV6
     Error join(const IPV6Multicast &ia);
@@ -340,6 +341,7 @@ protected:
      * @return 0 (errSuccess) on success, else error code.
      * @param ia address of multicast group to drop.
      */
+    Error drop(const ucommon::Socket::address &ia);
     Error drop(const IPV4Multicast &ia);
 #ifdef  CCXX_IPV6
     Error drop(const IPV6Multicast &ia);
@@ -496,9 +498,11 @@ public:
      * @param port ptr to port number of sender.
      * @return host address, test with "isInetAddress()".
      */
+    ucommon::Socket::address getSender() const;
+
     virtual IPV4Host getIPV4Sender(tpport_t *port = NULL) const;
 
-    inline IPV4Host getSender(tpport_t *port = NULL) const
+    inline IPV4Host getSender(tpport_t *port) const
         {return getIPV4Sender(port);}
 
 #ifdef  CCXX_IPV6
@@ -514,9 +518,11 @@ public:
      * @param port ptr to port number of remote socket.
      * @return host address of remote socket.
      */
+    ucommon::Socket::address getPeer() const;
+
     IPV4Host getIPV4Peer(tpport_t *port = NULL) const;
 
-    inline IPV4Host getPeer(tpport_t *port = NULL) const
+    inline IPV4Host getPeer(tpport_t *port) const
         {return getIPV4Peer(port);}
 
 #ifdef  CCXX_IPV6
@@ -532,13 +538,15 @@ public:
      */
     IPV4Host getIPV4Local(tpport_t *port = NULL) const;
 
-    inline IPV4Host getLocal(tpport_t *port = NULL) const
+    inline IPV4Host getLocal(tpport_t *port) const
         {return getIPV4Local(port);}
 
 #ifdef  CCXX_IPV6
     IPV6Host getIPV6Local(tpport_t *port = NULL) const;
 #endif
 
+    ucommon::Socket::address getLocal() const;
+
     /**
      * Used to specify blocking mode for the socket.  A socket
      * can be made non-blocking by setting setCompletion(false)
@@ -603,7 +611,7 @@ public:
      * @return true if broadcast socket.
      */
     inline bool isBroadcast(void) const
-        {return flags.broadcast;};
+        {return flags.broadcast;}
 
     /**
      * Return if socket routing is enabled.
@@ -611,7 +619,7 @@ public:
      * @return true if routing enabled.
      */
     inline bool isRouted(void) const
-        {return flags.route;};
+        {return flags.route;}
 
 
     inline struct in_addr getaddress(const IPV4Address &ia)
@@ -633,14 +641,14 @@ private:
 
 public:
     inline SockException(const String &str, Socket::Error socketError, long systemError = 0) :
-        IOException(str, systemError), _socketError(socketError) {};
+        IOException(str, systemError), _socketError(socketError) {}
 
     inline Socket::Error getSocketError() const
-    { return _socketError; }
+        {return _socketError;}
 };
 
 #endif
 
-END_NAMESPACE
+} // namespace ost
 
 #endif
